@@ -15,6 +15,7 @@ import json
 import logging
 import os.path
 import requests
+import pytz
 import sys
 
 import caep
@@ -48,7 +49,7 @@ def get_input(beanstalk_client: Optional[greenstalk.Client] = None) -> addict.Di
         job = beanstalk_client.reserve()
         try:
             nlpdata = addict.Dict(json.loads(gzip.decompress(job.body)))
-            logging.info(nlpdata.keys())
+            logging.info("Started work on %s", nlpdata.get("hexdigest", "No Hexdigest"))
         except OSError as e:
             # File not found - log error
             logging.error(e)
@@ -66,8 +67,11 @@ async def analyze(plugins: List[plugin.BasePlugin],
     loop = asyncio.get_event_loop()
 
     nlpdata: addict.Dict = get_input(beanstalk_client)
+    if not nlpdata.content:
+        logging.error("Missing content")
+        return addict.Dict({})
 
-    nlpdata["Analyzed-Date"] = datetime.datetime.now().isoformat()
+    nlpdata["Analyzed-Date"] = datetime.datetime.utcnow().replace(tzinfo=pytz.UTC).isoformat()
 
     # make sure we have a Creation-Date field even though the
     # document did not contain one. When missing, use current analyzed time.
@@ -147,6 +151,8 @@ async def async_main() -> None:
             raise
 
         result = task.result()
+        if not result:
+            continue
         result_json = json.dumps(result, indent="  ")
 
         if args.webdump:
@@ -159,7 +165,7 @@ async def async_main() -> None:
             if r.status_code != 200:
                 logging.error("Unable to post result data to webdump: %s", r.text)
 
-        elif elasticsearch_client:
+        if elasticsearch_client:
             hexdigest = result.get("hexdigest")
 
             if not hexdigest:
@@ -168,7 +174,8 @@ async def async_main() -> None:
                 elasticsearch_client.index(index="scio2", id=hexdigest, body=result)
                 logging.info("Stored %s to elasticsearch", hexdigest)
 
-        else:
+        if not (args.webdump or elasticsearch_client):
+            # Print to stdout if we do not send to webdump or elasticsearch
             print(result_json)
 
         # If we are not listening on a beanstalk work queue, behave like a command line
